"""
.. toctree::

.. autosummary::
   :toctree:

    diag
    initdb
    initdb_demo
    makedocs
    makescreenshots
    makeui
    mergedata
    monitor
    show
    syncscreenshots



"""
